
QSARmil - molecular multi-instance machine learning
============================================================
``QSARmil`` is a package for designing pipelines for building QSAR models with multi-instance machine learning algorithms.

Introduction
------------
Multi-instance machine learning for molecules.

Installation
------------

.. code-block:: bash

    pip install qsarmil

Quick start
------------

See the examples of ``QSARmil`` application for different tasks in the `tutorial collection <notebooks>`_ .